@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -127,6 +127,42 @@ class CloudRedisAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return CloudRedisClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> CloudRedisTransport:
         """Returns the transport used by the client instance.
@@ -207,6 +243,27 @@ class CloudRedisAsyncClient:
         regions available to the project are queried, and the results
         are aggregated.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_list_instances():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.ListInstancesRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_instances(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.ListInstancesRequest, dict]):
                 The request object. Request for
@@ -236,7 +293,7 @@ class CloudRedisAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -289,6 +346,25 @@ class CloudRedisAsyncClient:
     ) -> cloud_redis.Instance:
         r"""Gets the details of a specific Redis instance.
 
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_get_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.GetInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.GetInstanceRequest, dict]):
                 The request object. Request for
@@ -309,10 +385,10 @@ class CloudRedisAsyncClient:
 
         Returns:
             google.cloud.redis_v1beta1.types.Instance:
-                A Google Cloud Redis instance.
+                A Memorystore for Redis instance.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -362,6 +438,26 @@ class CloudRedisAsyncClient:
         This information is not included in the details returned
         to GetInstance.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_get_instance_auth_string():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.GetInstanceAuthStringRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_instance_auth_string(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.GetInstanceAuthStringRequest, dict]):
                 The request object. Request for
@@ -385,7 +481,7 @@ class CloudRedisAsyncClient:
                 Instance AUTH string details.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -447,6 +543,37 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a few
         hours, so there is no need to call DeleteOperation.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_create_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                instance = redis_v1beta1.Instance()
+                instance.name = "name_value"
+                instance.tier = "STANDARD_HA"
+                instance.memory_size_gb = 1499
+
+                request = redis_v1beta1.CreateInstanceRequest(
+                    parent="parent_value",
+                    instance_id="instance_id_value",
+                    instance=instance,
+                )
+
+                # Make the request
+                operation = client.create_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.CreateInstanceRequest, dict]):
                 The request object. Request for
@@ -491,11 +618,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, instance_id, instance])
         if request is not None and has_flattened_params:
@@ -560,6 +687,35 @@ class CloudRedisAsyncClient:
         operation is automatically deleted after a few hours, so
         there is no need to call DeleteOperation.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_update_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                instance = redis_v1beta1.Instance()
+                instance.name = "name_value"
+                instance.tier = "STANDARD_HA"
+                instance.memory_size_gb = 1499
+
+                request = redis_v1beta1.UpdateInstanceRequest(
+                    instance=instance,
+                )
+
+                # Make the request
+                operation = client.update_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.UpdateInstanceRequest, dict]):
                 The request object. Request for
@@ -598,11 +754,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([update_mask, instance])
         if request is not None and has_flattened_params:
@@ -663,6 +819,31 @@ class CloudRedisAsyncClient:
         r"""Upgrades Redis instance to the newer Redis version
         specified in the request.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_upgrade_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.UpgradeInstanceRequest(
+                    name="name_value",
+                    redis_version="redis_version_value",
+                )
+
+                # Make the request
+                operation = client.upgrade_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.UpgradeInstanceRequest, dict]):
                 The request object. Request for
@@ -694,11 +875,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, redis_version])
         if request is not None and has_flattened_params:
@@ -764,6 +945,34 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_import_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                input_config = redis_v1beta1.InputConfig()
+                input_config.gcs_source.uri = "uri_value"
+
+                request = redis_v1beta1.ImportInstanceRequest(
+                    name="name_value",
+                    input_config=input_config,
+                )
+
+                # Make the request
+                operation = client.import_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.ImportInstanceRequest, dict]):
                 The request object. Request for
@@ -795,11 +1004,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, input_config])
         if request is not None and has_flattened_params:
@@ -861,6 +1070,34 @@ class CloudRedisAsyncClient:
         The returned operation is automatically deleted after a
         few hours, so there is no need to call DeleteOperation.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_export_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                output_config = redis_v1beta1.OutputConfig()
+                output_config.gcs_destination.uri = "uri_value"
+
+                request = redis_v1beta1.ExportInstanceRequest(
+                    name="name_value",
+                    output_config=output_config,
+                )
+
+                # Make the request
+                operation = client.export_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.ExportInstanceRequest, dict]):
                 The request object. Request for
@@ -892,11 +1129,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, output_config])
         if request is not None and has_flattened_params:
@@ -956,6 +1193,30 @@ class CloudRedisAsyncClient:
         replica node for a specific STANDARD tier Cloud
         Memorystore for Redis instance.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_failover_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.FailoverInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.failover_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.FailoverInstanceRequest, dict]):
                 The request object. Request for
@@ -988,11 +1249,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, data_protection_mode])
         if request is not None and has_flattened_params:
@@ -1050,6 +1311,30 @@ class CloudRedisAsyncClient:
         r"""Deletes a specific Redis instance.  Instance stops
         serving and data is deleted.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_delete_instance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.DeleteInstanceRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_instance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.DeleteInstanceRequest, dict]):
                 The request object. Request for
@@ -1088,7 +1373,7 @@ class CloudRedisAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1146,6 +1431,31 @@ class CloudRedisAsyncClient:
         r"""Reschedule maintenance for a given instance in a
         given project and location.
 
+
+        .. code-block::
+
+            from google.cloud import redis_v1beta1
+
+            def sample_reschedule_maintenance():
+                # Create a client
+                client = redis_v1beta1.CloudRedisClient()
+
+                # Initialize request argument(s)
+                request = redis_v1beta1.RescheduleMaintenanceRequest(
+                    name="name_value",
+                    reschedule_type="SPECIFIC_TIME",
+                )
+
+                # Make the request
+                operation = client.reschedule_maintenance(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.redis_v1beta1.types.RescheduleMaintenanceRequest, dict]):
                 The request object. Request for
@@ -1185,11 +1495,11 @@ class CloudRedisAsyncClient:
 
                 The result type for the operation will be
                 :class:`google.cloud.redis_v1beta1.types.Instance` A
-                Google Cloud Redis instance.
+                Memorystore for Redis instance.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, reschedule_type, schedule_time])
         if request is not None and has_flattened_params:
