@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.redis_v1beta1.types import cloud_redis
@@ -74,14 +74,14 @@ class ListInstancesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[cloud_redis.ListInstancesResponse]:
+    def pages(self) -> Iterator[cloud_redis.ListInstancesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[cloud_redis.Instance]:
+    def __iter__(self) -> Iterator[cloud_redis.Instance]:
         for page in self.pages:
             yield from page.instances
 
@@ -136,14 +136,14 @@ class ListInstancesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[cloud_redis.ListInstancesResponse]:
+    async def pages(self) -> AsyncIterator[cloud_redis.ListInstancesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[cloud_redis.Instance]:
+    def __aiter__(self) -> AsyncIterator[cloud_redis.Instance]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.instances:
